﻿# Changelog



\- \*\*v1.0.0\*\* – 2025-08-25  

&nbsp; - First public release as an executable.



\- \*\*v1.1.0\*\* – 2025-10-28  

&nbsp; - Released as a Python package on PyPI.  

&nbsp; - Added the ability to enter custom PDF equations.



\- \*\*v1.1.1\*\* – 2025-10-29  

&nbsp; - Fixed issues related to faulty data upload.



\- \*\*v1.1.3\*\* – 2025-11-04  

&nbsp; - Fixed bug involving unenforced mass limits while viewing prior monochromatic spectra.  

&nbsp; - Tweaked plot labeling for increased legibility.  

&nbsp; - Added the ability to view previously generated histograms.



\- \*\*v1.1.4\*\* – 2025-11-22  

&nbsp; - Reformatted paper and README for compatibility.  

&nbsp; - Comment inputs beginning with a pound sign (`#`) are ignored, allowing example runs to be directly copy-pasted into a terminal.

